@@ -12,3 +12,14 @@ impl fmt::Display for CedictEntryError {
 }
 
 impl error::Error for CedictEntryError {}
+
+#[derive(Debug, Clone, PartialEq, Eq)]
+pub struct CedictError;
+
+impl fmt::Display for CedictError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "invalid cedict input")
+    }
+}
+
+impl error::Error for CedictError {}
